@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "leaf" "4.1.0"
+(define-package "leaf" "20260302.652"
   "Simplify your init.el configuration, extended use-package."
-  '((emacs "24.4"))
+  '((emacs "24.1"))
   :url "https://github.com/conao3/leaf.el"
-  :commit "0841ab466a1542868b5448bb375ac9f0c33e2b3f"
-  :revdesc "0841ab466a15"
+  :commit "b49e68613b8efba89c702141f49ad9b4460a7204"
+  :revdesc "b49e68613b8e"
   :keywords '("lisp" "settings")
   :authors '(("Naoya Yamashita" . "conao3@gmail.com"))
   :maintainers '(("Naoya Yamashita" . "conao3@gmail.com")))
